@@ -1271,6 +1271,27 @@ class Test_counts(config.Action_with_prefix):
             
                 only_tell=only_tell
                 )
+
+    def report(self, reporter):
+        prefix = os.path.basename(self.prefix)
+        image = reporter.get(self.prefix + '-heatmap.png', image=True, title='')
+        sig_csv = reporter.get(self.prefix + '.csv', title='[DE genes table]')
+        all_csv = reporter.get(self.prefix + '-all.csv', title='[All genes table]')
+        maybe_maplot = (
+            (' &sdot; ' + reporter.get(self.prefix+'.png', image=True,title='[MA-plot]'))
+            if os.path.exists(self.prefix+'.png') else ''
+            )
+        info = reporter.get(self.prefix + '-info.txt', title='[Info]')        
+        
+        text = (
+            '<table><tr>\n'
+            '<td valign="top">%(image)s</td>\n'
+            '<td valign="top"><b>%(prefix)s</b>\n'
+            '<br/>%(sig_csv)s &sdot; %(all_csv)s &sdot; %(info)s %(maybe_maplot)s\n'
+            '</tr></table>'
+            ) % locals()
+        
+        reporter.write(text)
             
 
 
@@ -1625,6 +1646,138 @@ class Heatmap(config.Action_with_prefix):
         )
 
 
+
+
+SIMILARITY_SCRIPT = """
+
+library(nesoni)
+
+dgelist <- read.counts(COUNTS, norm.file=NORM_FILE)
+
+if (length(ORDER)) {
+    dgelist <- dgelist[, ORDER]
+}
+
+elist <- glog2.rpm.counts(dgelist, GLOG_MODERATION)
+mat <- elist$E
+
+sink(sprintf("%s.nex", PREFIX))
+cat("#NEXUS\n")
+cat("begin taxa;\n")
+cat(sprintf("dimensions ntax=%d;\n",ncol(mat)))
+cat("taxlabels\n")
+for(i in basic.seq(ncol(mat))) {
+    cat(sprintf("%s\n", colnames(mat)[i]));
+}
+cat(";\n")
+cat("end;\n")
+cat("begin distances;\n")
+cat("format triangle=lower diagonal nolabels;\n")
+cat("matrix\n")
+for(i in basic.seq(ncol(mat))) {
+    for(j in basic.seq(i)) {
+        diff <- mat[,j]-mat[,i]
+        dist <- sqrt(mean(diff*diff))
+        cat(sprintf("%f ",dist));
+    }
+    cat("\n")
+}
+cat(";\n")
+cat("end;\n")
+sink()
+
+library(limma)
+png(sprintf("%s-plotMDS.png",PREFIX),width=800,height=800)
+plotMDS(elist)
+dev.off()
+
+"""
+
+
+@config.help("""\
+The similarity/difference between samples is visualized in several ways:
+
+- The plotMDS function from limma.
+
+- A SplitsTree4 generated NeighborNet based on root mean square difference in glog2 gene expression level between each pair of samples.
+
+These plots may be helpful in identifying contaminated or mislabeled samples.
+""")
+@config.Float_flag('glog_moderation', 
+    'Amount of moderation used in log transformation.'
+    ' See "glog" mode in "test-counts:".'
+    )
+@config.String_flag('norm_file', 'Use normalization produced by "norm-from-counts:".')
+@config.Positional('counts', 'File containing output from "nesoni count:"')
+@config.String_flag('select', 'Selection expression (see main help text). Which samples to use.')
+#@config.String_flag('sort', 'A sort expression to sort samples (see main help text).')
+class Similarity(config.Action_with_prefix):
+    glog_moderation = 5.0
+    counts = None
+    norm_file = None
+    select = 'all'
+    sort = ''
+
+    def run(self):
+        reader = io.Table_reader(self.counts, 'Count')
+        reader.close()
+        all_samples = [ item for i, item in enumerate(reader.headings) if reader.groups[i] == 'Count' ]
+        tags = { }
+        for item in all_samples:
+            tags[item] = [ item ]
+        for line in reader.comments:
+            if line.startswith('#sampleTags='):
+                parts = line[len('#sampleTags='):].split(',')
+                tags[parts[0]] = parts
+            
+        samples = selection.select_and_sort(
+            self.select, self.sort, all_samples, lambda sample: tags[sample])
+
+        run_script(SIMILARITY_SCRIPT,
+            PREFIX=self.prefix,
+            GLOG_MODERATION=self.glog_moderation,
+            COUNTS=self.counts,
+            NORM_FILE=self.norm_file,
+            ORDER=samples,
+        )
+
+        io.execute(
+            'SplitsTree +g -i INPUT -x COMMAND',
+            INPUT=self.prefix + '.nex',
+            COMMAND='UPDATE; '
+                    'SAVE FILE=\'%s.nex\' REPLACE=yes; '
+                    'EXPORTGRAPHICS format=svg file=\'%s.svg\' REPLACE=yes TITLE=\'NeighborNet of expression levels\'; ' 
+                    'QUIT' 
+                    % (self.prefix, self.prefix),
+            )
+
+    def report(self, reporter):    
+        reporter.heading('Sample similarity')
+        
+        reporter.p(
+            'The following plots attempt to summarize the similarity/differences in expression patterns between samples, '
+            'based on the glog2-transformed normalized read counts. '
+            'Samples from the same experimental group should cluster together.'
+            )
+        
+        reporter.p(
+            reporter.get(self.prefix + '-plotMDS.png',
+                title = 'limma\'s "plotMDS" Multi-Dimensional Scaling plot of sample similarity',
+                image = True
+                )
+            )
+        
+        reporter.p(
+            reporter.get(self.prefix + '.svg',
+                title = 'Split Network visualization of sample similarity.',
+                image = True
+                ) +
+            '<br>(Visualization of euclidean distances as a split network. '
+            'Note: This is <i>not</i> a phylogenetic network.)'
+            )
+
+
+
 COMPARE_TESTS_SCRIPT = """
 
 library(nesoni)
